@@ -14,16 +14,15 @@ from dagster import (
     MetadataEntry,
     StringSource,
     TypeCheck,
-    check,
-    dagster_type_loader,
-    dagster_type_materializer,
 )
-from dagster.check import CheckError
-from dagster.config.field_utils import Selector
-from dagster.core.definitions.metadata import normalize_metadata
-from dagster.core.errors import DagsterInvalidMetadata
-from dagster.utils import dict_without_keys
-from dagster.utils.backcompat import experimental
+from dagster import _check as check
+from dagster import dagster_type_loader, dagster_type_materializer
+from dagster._annotations import experimental
+from dagster._check import CheckError
+from dagster._config import Selector
+from dagster._core.definitions.metadata import normalize_metadata
+from dagster._core.errors import DagsterInvalidMetadata
+from dagster._utils import dict_without_keys
 
 CONSTRAINT_BLACKLIST = {ColumnDTypeFnConstraint, ColumnDTypeInSetConstraint}
 
@@ -97,9 +96,9 @@ def df_type_check(_, value):
     return TypeCheck(
         success=True,
         metadata_entries=[
-            MetadataEntry.text(str(len(value)), "row_count", "Number of rows in DataFrame"),
+            MetadataEntry("row_count", value=str(len(value))),
             # string cast columns since they may be things like datetime
-            MetadataEntry.json({"columns": list(map(str, value.columns))}, "metadata"),
+            MetadataEntry("metadata", value={"columns": list(map(str, value.columns))}),
         ],
     )
 
@@ -112,6 +111,7 @@ DataFrame = DagsterType(
     loader=dataframe_loader,
     materializer=dataframe_materializer,
     type_check_fn=df_type_check,
+    typing_type=pd.DataFrame,
 )
 
 
@@ -204,7 +204,9 @@ def create_dagster_pandas_dataframe_type(
 
         try:
             validate_constraints(
-                value, pandas_columns=columns, dataframe_constraints=dataframe_constraints
+                value,
+                pandas_columns=columns,
+                dataframe_constraints=dataframe_constraints,
             )
         except ConstraintViolationException as e:
             return TypeCheck(success=False, description=str(e))
@@ -293,9 +295,9 @@ def create_structured_dataframe_type(
             typechecks_succeeded = typechecks_succeeded and result_val
             result_dict = result.metadata_entries[0].entry_data.data
             metadata.append(
-                MetadataEntry.json(
-                    result_dict,
+                MetadataEntry(
                     "{}-constraint-metadata".format(key),
+                    value=result_dict,
                 )
             )
             constraint_clauses.append("{} failing constraints, {}".format(key, result.description))
