@@ -2,7 +2,6 @@ import dagster_pandas as dagster_pd
 import dagstermill
 
 from dagster import In, Out, file_relative_path, op
-from dagster._legacy import InputDefinition, OutputDefinition
 
 from ...data_frame import DataFrame
 
@@ -39,9 +38,9 @@ def nb_test_path(name):
     return file_relative_path(__file__, "../notebooks/{name}.ipynb".format(name=name))
 
 
-papermill_pandas_hello_world = dagstermill.factory.define_dagstermill_solid(
+papermill_pandas_hello_world = dagstermill.factory.define_dagstermill_op(
     name="papermill_pandas_hello_world",
     notebook_path=nb_test_path("papermill_pandas_hello_world"),
-    input_defs=[InputDefinition(name="df", dagster_type=DataFrame)],
-    output_defs=[OutputDefinition(DataFrame)],
+    ins={"df": In(DataFrame)},
+    outs={"result": Out(DataFrame)},
 )
